"""Top-level package for Django lookup extensions."""

__author__ = """UNCOVER TRUTH Inc."""
__email__ = 'develop@uncovertruth.co.jp'
__version__ = '0.0.2'

default_app_config = 'lookup_extensions.apps.LookupExtensionsConfig'
